==> hscloud-0.0.0.7.tar.gz: hscloud-0.0.0.7/hscloud/helpers.py <==
import requests
from datetime import datetime
from typing import Optional
import logging

logger = logging.getLogger(__name__)

class Helpers:

    @staticmethod
    def login(username=None, password=None):
        base_url = 'http://10.10.20.109:2070'

        headers = {
            'Content-Type': 'application/json',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        body = {
            "client_id": "89ef537b2202481aaaf9077068bcb0c9",
            "client_secret": "41b20a1f60e9499e89c8646c31f93ea1",
            "grant_type": "openapi",
            "scope": "all",
            "email": username,
            "password": password
        }

        return Helpers.call_api(base_url + "/api/oauth/login", "post", headers, params, body)

    @staticmethod
    def devices(endpoint=None, access_token=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/list", "get", headers, params)

    @staticmethod
    def status(endpoint=None, access_token=None, devicesn=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'deviceSn': devicesn,
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/state", "get", headers, params)

    @staticmethod
    def update(endpoint=None, access_token=None, devicesn=None,  **kwargs):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/control", "post", headers, params, Helpers.update_body(devicesn, **kwargs))

    @staticmethod
    def call_api(api: str, method: str, headers: Optional[dict] = None, params: Optional[dict] = None, json_body: Optional[dict] = None) -> tuple:
        response = None
        try:
            if method.lower() == "get":
                response = requests.get(api, headers=headers, params=params, timeout=8)

            elif method.lower() == "post":
                response = requests.post(api, headers=headers, params=params, json=json_body, timeout=8)

        except requests.exceptions.RequestException as e:
            logger.error(e)
        except Exception as e:
            logger.error(e)
        else:
            if response.status_code == 200:
                response_body = response.json()
                code = response_body.get("code")
                if code == 0:
                    response = response_body.get("data")
                elif code == 401:
                    logger.error("Cannot execute request. token invalid. Make sure to login.")
                else:
                    logger.error(response_body.get("msg"))

            elif response.status_code == 429:
                logger.error("Your request is too frequent, please try again later.")
            else:
                logger.error("There is a service problem, please try again later.")

        return response

    @staticmethod
    def update_body(devicesn, **kwargs):
        data = {
            'devicesn': devicesn
        }

        desired = {}
        for key, value in kwargs.items():
            desired.update({key: value})

        data.update({'desired': desired})
        return data

    @staticmethod
    def timestamp():
        return int(datetime.now().timestamp() * 1000)

==> hscloud-0.0.0.8.tar.gz: hscloud-0.0.0.8/hscloud/helpers.py <==
import requests
from datetime import datetime
from typing import Optional
import logging

logger = logging.getLogger(__name__)

class Helpers:

    @staticmethod
    def login(username=None, password=None):
        base_url = 'http://10.10.20.109:2070'

        headers = {
            'Content-Type': 'application/json',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        body = {
            "client_id": "89ef537b2202481aaaf9077068bcb0c9",
            "client_secret": "41b20a1f60e9499e89c8646c31f93ea1",
            "grant_type": "openapi",
            "scope": "all",
            "email": username,
            "password": password
        }

        return Helpers.call_api(base_url + "/api/oauth/login", "post", headers, params, body)

    @staticmethod
    def devices(endpoint=None, access_token=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/list", "get", headers, params)

    @staticmethod
    def status(endpoint=None, access_token=None, devicesn=None):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'deviceSn': devicesn,
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/state", "get", headers, params)

    @staticmethod
    def update(endpoint=None, access_token=None, devicesn=None,  **kwargs):
        headers = {
            'Content-Type': 'application/json',
            'Authorization': f'Bearer {access_token}',
            'UA': 'openapi/1.0.0'
        }

        params = {
            'timestamp': Helpers.timestamp()
        }

        return Helpers.call_api(endpoint + "/api/device/control", "post", headers, params, Helpers.update_body(devicesn, **kwargs))

    @staticmethod
    def call_api(api: str, method: str, headers: Optional[dict] = None, params: Optional[dict] = None, json_body: Optional[dict] = None) -> tuple:
        result = None
        response = None
        try:
            if method.lower() == "get":
                response = requests.get(api, headers=headers, params=params, timeout=8)

            elif method.lower() == "post":
                response = requests.post(api, headers=headers, params=params, json=json_body, timeout=8)

        except requests.exceptions.RequestException as e:
            logger.error(e)
        except Exception as e:
            logger.error(e)
        else:
            if response.status_code == 200:
                response_body = response.json()
                code = response_body.get("code")
                if code == 0:
                    result = response_body.get("data")
                elif code == 401:
                    logger.error("Cannot execute request. token invalid. Make sure to login.")
                else:
                    logger.error(response_body.get("msg"))

            elif response.status_code == 429:
                logger.error("Your request is too frequent, please try again later.")
            else:
                logger.error("There is a service problem, please try again later.")

        return result

    @staticmethod
    def update_body(devicesn, **kwargs):
        data = {
            'devicesn': devicesn
        }

        desired = {}
        for key, value in kwargs.items():
            desired.update({key: value})

        data.update({'desired': desired})
        return data

    @staticmethod
    def timestamp():
        return int(datetime.now().timestamp() * 1000)
